import { css } from 'emotion';
import * as React from 'react';
import { styled } from 'styles';

// import { hsla } from 'styles/colors';
import { typographicStyles } from 'styles/typography/typography.styles';
// import { ColorVariantsHsla, ITheme, Theme } from 'types/styles';
import { ITheme, Theme } from 'types/styles';

interface IButtonProps {
  children: React.ReactNode;
  variant?: 'text' | 'outlined' | 'contained' | 'toggle';
  isDense?: boolean;
  isElevated?: boolean;
  disabled?: boolean;
}

interface IButtonPropsWithTheme extends ITheme, IButtonProps {}

const getButtonStyles = (theme: Theme) => css`
  ${typographicStyles.button};
  min-width: ${theme.button.width.minWidthPx}px;
  display: inline-flex;
  position: relative;
  align-items: center;
  justify-content: center;
  border: none;
  outline: none;
  line-height: inherit;
  user-select: none;
  appearance: none;
  overflow: hidden;
  vertical-align: middle;

  &::-moz-focus-inner {
    padding: 0;
    border: 0;
  }

  &:active {
    outline: none;
  }

  &:hover {
    cursor: pointer;
  }

  &:disabled {
    cursor: default;
    pointer-events: none;
    color: ${theme.colors.element.surface.onColor.faint};
    background-color: ${theme.colors.element.surface.color};
  }
`;

const getButtonVariantStyles = (
  theme: Theme,
  variant: IButtonProps['variant'],
  isDense: IButtonProps['isDense'],
  isElevated: IButtonProps['isElevated']
) => {
  console.log('theme', theme);
  return css``;
  // const brandPrimary = theme.colors.brand.primary as ColorVariantsHsla;

  // // const heightValue = isDense
  // // ? theme.button.heightPx.dense
  // // : theme.button.heightPx.standard;
  // // css`height: ${heightValue}px;
  // // line-height: ${heightValue}px`;

  // const OutlinedAndContainedStyles = css`
  //   padding: 0 ${theme.button.width.horizontalPaddingPx.contained}px;
  // `;

  // const TextAndOutlinedStyles = css`
  //   color: ${brandPrimary.standard.color};
  //   background-color: transparent;
  // `;

  // switch (variant) {
  //   case 'outlined':
  //     return css`
  //       ${TextAndOutlinedStyles};
  //       ${OutlinedAndContainedStyles};
  //       border-width: 2px;
  //       border-color: ${brandPrimary.standard.color};
  //       &:disabled {
  //         border-color: ${theme.colors.element.surface.onColor.faint};
  //       }
  //     `;
  //   case 'contained':
  //     return css`
  //       ${OutlinedAndContainedStyles};
  //       color: ${brandPrimary.standard.onColor.regular};
  //       background-color: ${brandPrimary.standard.color};
  //     `;
  //   case 'text':
  //     return css`
  //       ${TextAndOutlinedStyles}
  //       padding: 0 ${theme.button.width.horizontalPaddingPx.text}px;
  //     `;
  //   default:
  //     return;
  // }
};

const StyledButton = styled('button')`
  ${(props: IButtonPropsWithTheme) => {
    const { variant, theme, isDense, isElevated } = props;

    return css`
      ${getButtonStyles(theme!)};
      ${getButtonVariantStyles(theme!, variant, isDense, isElevated)};
    `;
  }};
`;

const Button: React.SFC<IButtonProps> = ({ children, disabled, ...rest }) => (
  <StyledButton disabled={disabled} {...rest}>
    {children}
  </StyledButton>
);

Button.defaultProps = {
  variant: 'text',
  isDense: false,
  isElevated: false,
};

export default Button;
