import { css, cx } from 'emotion';
import * as React from 'react';

import { typographicStyles } from 'styles/typography';
import { TypographicStyles } from 'types/components/atoms/typographicStyle';

interface ITypographicStyleVariantProps {
  children: React.ReactNode;
  styledAs?: TypographicStyles;
  className?: string;
}

interface ITypographicStyleProps extends ITypographicStyleVariantProps {
  variant: TypographicStyles;
}

const getTypographicStyleHtmlElement = (typograhicStyle: TypographicStyles) => {
  switch (typograhicStyle) {
    case 'subtitle1':
    case 'subtitle2':
      return 'h6';
    case 'body1':
    case 'body2':
      return 'p';
    case 'caption':
    case 'overline':
      return 'span';
    default:
      return typograhicStyle;
  }
};

const TypographicStyle: React.SFC<ITypographicStyleProps> = ({
  children,
  variant,
  className,
  styledAs,
  ...rest
}) => {
  const HtmlElement = getTypographicStyleHtmlElement(variant);

  /** This enables margins to appear. Inline elements do not show margins. */
  const spanStyle = css`
    display: inline-flex;
  `;

  const style = styledAs
    ? typographicStyles[styledAs]
    : typographicStyles[variant];

  return (
    <HtmlElement
      className={cx(style, HtmlElement === 'span' && spanStyle, className)}
    >
      {children}
    </HtmlElement>
  );
};

TypographicStyle.defaultProps = {
  variant: 'body2',
};

export default TypographicStyle;

export const H1: React.SFC<ITypographicStyleVariantProps> = props => (
  <TypographicStyle variant="h1" {...props} />
);

export const H2: React.SFC<ITypographicStyleVariantProps> = props => (
  <TypographicStyle variant="h2" {...props} />
);

export const H3: React.SFC<ITypographicStyleVariantProps> = props => (
  <TypographicStyle variant="h3" {...props} />
);

export const H4: React.SFC<ITypographicStyleVariantProps> = props => (
  <TypographicStyle variant="h4" {...props} />
);

export const H5: React.SFC<ITypographicStyleVariantProps> = props => (
  <TypographicStyle variant="h5" {...props} />
);

export const H6: React.SFC<ITypographicStyleVariantProps> = props => (
  <TypographicStyle variant="h6" {...props} />
);

export const Subtitle1: React.SFC<ITypographicStyleVariantProps> = props => (
  <TypographicStyle variant="subtitle1" {...props} />
);

export const Subtitle2: React.SFC<ITypographicStyleVariantProps> = props => (
  <TypographicStyle variant="subtitle2" {...props} />
);

export const Body1: React.SFC<ITypographicStyleVariantProps> = props => (
  <TypographicStyle variant="body1" {...props} />
);

export const Body2: React.SFC<ITypographicStyleVariantProps> = props => (
  <TypographicStyle variant="body2" {...props} />
);

export const Caption: React.SFC<ITypographicStyleVariantProps> = props => (
  <TypographicStyle variant="caption" {...props} />
);

export const Overline: React.SFC<ITypographicStyleVariantProps> = props => (
  <TypographicStyle variant="overline" {...props} />
);
