import { css } from 'emotion';

import { mq } from 'styles/media/utils.styles';
import { typographyFoundation } from 'styles/typography/variables.styles';
import { EnumBreakpoints as bp } from 'types/styles';

/**
 * Add missing resets when necessary for: fieldset, legend, progress, textarea,
 * checkbox (IE), radio (IE), increment/decrement buttons (Chrome), details,
 * summary
 * [Partially copied from Normalize 8.0.0]{@link https://necolas.github.io/normalize.css/8.0.0/normalize.css}
 */
export const globalBaseStyles = css`
  *,
  *::before,
  *::after {
    box-sizing: inherit;
  }

  html {
    box-sizing: border-box;
  }

  /**
  * Removes all margins and adds a bottom margin
  */
  abbr,
  address,
  article,
  aside,
  audio,
  blockquote,
  canvas,
  caption,
  cite,
  code,
  dd,
  dl,
  dt,
  embed,
  fieldset,
  figure,
  form,
  hgroup,
  hr,
  iframe,
  kbd,
  label,
  legend,
  object,
  ol,
  optgroup,
  p,
  q,
  summary,
  table,
  ul,
  video {
    margin: ${typographyFoundation.leadingPx[bp.Mobile]}px 0;
    ${mq('tablet')} {
      margin-top: ${typographyFoundation.leadingPx[bp.Tablet]}px;
      margin-bottom: ${typographyFoundation.leadingPx[bp.Tablet]}px;
    }
  }

  body {
    margin: 0;
  }

  /* Embedded content
    ========================================================================== */

  /**
  * Remove the border on images inside links in IE 10.
  */
  img {
    border-style: none;
  }

  /* Forms
   ========================================================================== */

  /**
  * 1. Change the font styles in all browsers.
  * 2. Remove the margin in Firefox and Safari.
  */
  button,
  input,
  optgroup,
  select,
  textarea {
    font-family: inherit;
    font-size: 100%;
    margin: 0;
  }

  input:focus {
    outline: 0;
  }

  input[type='number']::-webkit-inner-spin-button,
  input[type='number']::-webkit-outer-spin-button {
    appearance: none;
    margin: 0;
  }

  /**
  * 1. Correct the odd appearance in Chrome and Safari.
  * 2. Correct the outline style in Safari.
  */
  [type='search'] {
    appearance: textfield; /* 1 */
    outline-offset: -2px; /* 2 */
  }

  /**
  * Remove the inner padding in Chrome and Safari on macOS.
  */
  [type='search']::-webkit-search-decoration {
    appearance: none;
  }

  /**
  * 1. Correct the inability to style clickable types in iOS and Safari.
  * 2. Change font properties to 'inherit' in Safari.
  */
  ::-webkit-file-upload-button {
    appearance: button; /* 1 */
    font: inherit; /* 2 */
  }
`;
