import { css } from 'emotion';
import { theme } from 'styles';
import { hsla } from 'styles/colors/utils.styles';
import {
  elevationAmbientShadow,
  elevationPenumbraShadow,
  elevationProperty,
  elevationUmbraShadow,
  shadowTransition,
} from './variables/shadows.styles';

const boxShadowValues = (
  offsetX: number,
  offsetY: number,
  blurRadius: number,
  spreadRadius: number
) => `${offsetX}px ${offsetY}px ${blurRadius}px ${spreadRadius}px`;

export const elevationShadowStyle = (
  zValue: number,
  color = theme.colors.element.shadow
) => {
  /** TODO: After this gets released (https://github.com/Microsoft/TypeScript/pull/24897), revert back to commented out code using spread operators */
  const umbraZValues = boxShadowValues(
    elevationUmbraShadow.shadows[zValue][0],
    elevationUmbraShadow.shadows[zValue][1],
    elevationUmbraShadow.shadows[zValue][2],
    elevationUmbraShadow.shadows[zValue][3]
  );
  const penumbraZValues = boxShadowValues(
    elevationPenumbraShadow.shadows[zValue][0],
    elevationPenumbraShadow.shadows[zValue][1],
    elevationPenumbraShadow.shadows[zValue][2],
    elevationPenumbraShadow.shadows[zValue][3]
  );
  const ambientZValues = boxShadowValues(
    elevationAmbientShadow.shadows[zValue][0],
    elevationAmbientShadow.shadows[zValue][1],
    elevationAmbientShadow.shadows[zValue][2],
    elevationAmbientShadow.shadows[zValue][3]
  );

  const umbraColor = hsla([
    color[0],
    color[1],
    color[2],
    elevationUmbraShadow.opacity,
  ]);
  const penumbraColor = hsla([
    color[0],
    color[1],
    color[2],
    elevationPenumbraShadow.opacity,
  ]);
  const ambientColor = hsla([
    color[0],
    color[1],
    color[2],
    elevationAmbientShadow.opacity,
  ]);

  // const umbraZValues = boxShadowValues(...elevationUmbraShadow.shadows[zValue]);
  // const penumbraZValues = boxShadowValues(
  //   ...elevationPenumbraShadow.shadows[zValue]
  // );
  // const ambientZValues = boxShadowValues(
  //   ...elevationAmbientShadow.shadows[zValue]
  // );
  //
  // const umbraColor = hsla(...color, elevationUmbraShadow.opacity);
  // const penumbraColor = hsla(...color, elevationPenumbraShadow.opacity);
  // const ambientColor = hsla(...color, elevationAmbientShadow.opacity);

  /* prettier-ignore */
  return css`
    box-shadow: ${umbraZValues} ${umbraColor},
      ${penumbraZValues} ${penumbraColor},
      ${ambientZValues} ${ambientColor};
  `;
};

export const elevationTransitionStyles = (
  duration = shadowTransition.duration,
  timingFunction = shadowTransition.timingFunction
) =>
  css`
    transition: ${elevationProperty} ${duration} ${timingFunction};
    will-change: ${elevationProperty};
  `;
