import { css } from 'emotion';

import { GridStylesOptions } from 'types/styles';
import {
  columnStyles,
  horizontalAndVerticalGutterStyles,
  horizontalAndVerticalMarginStyles,
  horizontalGutterStyles,
  horizontalMarginStyles,
  verticalGutterStyles,
  verticalMarginStyles,
} from './utils.styles';

export const gridStyles = (customOptions: GridStylesOptions) => {
  const options = {
    alignItems: '',
    justifyItems: '',
    horizontalGutters: true,
    verticalGutters: false,
    horizontalMargins: true,
    verticalMargins: true,
    ...customOptions,
  };

  return css`
    display: grid;
    justify-content: center;
    ${columnStyles};
    ${options.horizontalGutters &&
      !options.verticalGutters &&
      horizontalGutterStyles};
    ${options.verticalGutters &&
      !options.horizontalGutters &&
      verticalGutterStyles};
    ${options.horizontalGutters &&
      options.verticalGutters &&
      horizontalAndVerticalGutterStyles};
    ${options.horizontalMargins &&
      !options.verticalMargins &&
      horizontalMarginStyles};
    ${options.verticalMargins &&
      !options.horizontalMargins &&
      verticalMarginStyles};
    ${options.horizontalMargins &&
      options.verticalMargins &&
      horizontalAndVerticalMarginStyles};
    ${css({
      alignItems: options.alignItems,
      justifyItems: options.justifyItems,
    })};
  `;
};
