import { css } from 'emotion';
import { mqs } from 'styles/media/utils.styles';
import { EnumBreakpoints as bp } from 'types/styles';
import { layout } from './variables.styles';

const getColumnWidth = (
  maxGridWidthPx: number | null = null,
  columns: number,
  gutterSizePx: number
) =>
  maxGridWidthPx
    ? `minmax(0, ${maxGridWidthPx - gutterSizePx * (columns - 1)}px`
    : '1fr';

const makeGridColumns = (breakpointIndex: number, layoutValues = layout) => {
  const columns = layoutValues.columns[breakpointIndex];

  const columnWidth = getColumnWidth(
    layoutValues.maxGridWidthPx[breakpointIndex],
    columns,
    layoutValues.gutterSizePx[breakpointIndex]
  );

  return `repeat(${columns}, ${columnWidth})`;
};

export const columnStyles = css(
  mqs()({
    gridTemplateColumns: [
      makeGridColumns(bp.Mobile),
      makeGridColumns(bp.Tablet),
      makeGridColumns(bp.Desktop),
    ],
  })
);

export const horizontalGutterStyles = css(
  mqs()({
    gridGap: [
      `0 ${layout.gutterSizePx[bp.Mobile]}px`,
      `0 ${layout.gutterSizePx[bp.Tablet]}px`,
      `0 ${layout.gutterSizePx[bp.Desktop]}px`,
    ],
  })
);

export const verticalGutterStyles = css(
  mqs()({
    gridGap: [
      `${layout.gutterSizePx[bp.Mobile]}px 0`,
      `${layout.gutterSizePx[bp.Tablet]}px 0`,
      `${layout.gutterSizePx[bp.Desktop]}px 0`,
    ],
  })
);

export const horizontalAndVerticalGutterStyles = css(
  mqs()({
    gridGap: [
      layout.gutterSizePx[bp.Mobile] + 'px',
      layout.gutterSizePx[bp.Tablet] + 'px',
      layout.gutterSizePx[bp.Desktop] + 'px',
    ],
  })
);

export const horizontalMarginStyles = css(
  mqs()({
    paddingLeft: [
      layout.marginSizePx[bp.Mobile] + 'px',
      layout.marginSizePx[bp.Tablet] + 'px',
      layout.marginSizePx[bp.Desktop] + 'px',
    ],
    paddingRight: [
      layout.marginSizePx[bp.Mobile] + 'px',
      layout.marginSizePx[bp.Tablet] + 'px',
      layout.marginSizePx[bp.Desktop] + 'px',
    ],
  })
);

export const verticalMarginStyles = css(
  mqs()({
    paddingTop: [
      layout.marginSizePx[bp.Mobile] + 'px',
      layout.marginSizePx[bp.Tablet] + 'px',
      layout.marginSizePx[bp.Desktop] + 'px',
    ],
    paddingBottom: [
      layout.marginSizePx[bp.Mobile] + 'px',
      layout.marginSizePx[bp.Tablet] + 'px',
      layout.marginSizePx[bp.Desktop] + 'px',
    ],
  })
);

export const horizontalAndVerticalMarginStyles = css(
  mqs()({
    padding: [
      layout.marginSizePx[bp.Mobile] + 'px',
      layout.marginSizePx[bp.Tablet] + 'px',
      layout.marginSizePx[bp.Desktop] + 'px',
    ],
  })
);
