import { css } from 'emotion';

import { mqs } from 'styles/media/utils.styles';
import { getTypeElementStyles } from './utils.styles';
import { typeProperties, typographyFoundation } from './variables.styles';

/* prettier-ignore */
export const globalTypographyStyles = css`
  :root {
    ${mqs()({
      '--base-font-size': typographyFoundation.baseFontSizePx.map(fontSize => fontSize + 'px'),
      '--modular-ratio': typographyFoundation.modularRatio,
    })};

    --ms-1: calc(var(--modular-ratio) * 1rem);
    --ms-2: calc(var(--modular-ratio) * var(--ms-1));
    --ms-3: calc(var(--modular-ratio) * var(--ms-2));
    --ms-4: calc(var(--modular-ratio) * var(--ms-3));
    --ms-5: calc(var(--modular-ratio) * var(--ms-4));
    --ms-6: calc(var(--modular-ratio) * var(--ms-5));
  }

  html {
    font-family: ${typographyFoundation.fontFamily};
    font-size: var(--base-font-size);
    -text-size-adjust: 100%;
    -moz-osx-font-smoothing: grayscale;
    -webkit-font-smoothing: antialiased;
    ${mqs()({
      lineHeight: typographyFoundation.leadingPx.map(leading => leading + 'px'),
    })};
  }
`;

export const typographicStyles = {
  h1: getTypeElementStyles(typeProperties.h1),
  h2: getTypeElementStyles(typeProperties.h2),
  h3: getTypeElementStyles(typeProperties.h3),
  h4: getTypeElementStyles(typeProperties.h4),
  h5: getTypeElementStyles(typeProperties.h5),
  h6: getTypeElementStyles(typeProperties.h6),
  subtitle1: getTypeElementStyles(typeProperties.subtitle1),
  subtitle2: getTypeElementStyles(typeProperties.subtitle2),
  body1: getTypeElementStyles(typeProperties.body1),
  body2: getTypeElementStyles(typeProperties.body2),
  button: getTypeElementStyles(typeProperties.button),
  caption: getTypeElementStyles(typeProperties.caption),
  overline: getTypeElementStyles(typeProperties.overline),
};
