import { pointGridUnits } from 'styles/_helpers/utils/pointGridUnits.styles';
import {
  FontWeights,
  TypeProperties,
  TypographyFoundation,
} from 'types/styles';

export const typographyFoundation: TypographyFoundation = {
  baseFontSizePx: [16, 18],
  leadingPx: [pointGridUnits(5, 4), pointGridUnits(6, 4)],
  modularRatio: [1.25, 1.333],
  fontFamily: 'Roboto, sans-serif',
};

export const fontWeights: FontWeights = {
  thin: 100,
  light: 300,
  regular: 400,
  medium: 500,
  bold: 700,
  black: 900,
};

export const typeProperties: TypeProperties = {
  h1: {
    fontSize: ['modularScale', 6],
    fontWeight: fontWeights.light,
    letterSpacing: -1.5,
    lineHeightPx: [pointGridUnits(23, 4), pointGridUnits(26, 4)],
    marginTopPx: [pointGridUnits(12, 4), pointGridUnits(13, 4)],
    marginBottomPx: [pointGridUnits(12, 4), pointGridUnits(13, 4)],
  },
  h2: {
    fontSize: ['modularScale', 5],
    fontWeight: fontWeights.light,
    letterSpacing: -0.5,
    lineHeightPx: [pointGridUnits(18, 4), pointGridUnits(20, 4)],
    marginTopPx: [pointGridUnits(9, 4), pointGridUnits(10, 4)],
    marginBottomPx: [pointGridUnits(9, 4), pointGridUnits(10, 4)],
  },
  h3: {
    fontSize: ['modularScale', 4],
    fontWeight: fontWeights.regular,
    letterSpacing: 0,
    lineHeightPx: [pointGridUnits(14, 4), pointGridUnits(15, 4)],
    marginTopPx: [pointGridUnits(7, 4), pointGridUnits(8, 4)],
    marginBottomPx: [pointGridUnits(7, 4), pointGridUnits(8, 4)],
  },
  h4: {
    fontSize: ['modularScale', 3],
    fontWeight: fontWeights.regular,
    letterSpacing: 0.25,
    lineHeightPx: [pointGridUnits(11, 4), pointGridUnits(12, 4)],
    marginTopPx: [pointGridUnits(11, 4), pointGridUnits(12, 4)],
    marginBottomPx: [pointGridUnits(11, 4), pointGridUnits(12, 4)],
  },
  h5: {
    fontSize: ['modularScale', 2],
    fontWeight: fontWeights.regular,
    letterSpacing: 0,
    lineHeightPx: [pointGridUnits(8, 4), pointGridUnits(9, 4)],
    marginTopPx: [pointGridUnits(8, 4), pointGridUnits(9, 4)],
    marginBottomPx: [pointGridUnits(8, 4), pointGridUnits(9, 4)],
  },
  h6: {
    fontSize: ['modularScale', 1],
    fontWeight: fontWeights.medium,
    letterSpacing: 0.15,
    lineHeightPx: [pointGridUnits(6, 4), pointGridUnits(7, 4)],
    marginTopPx: [pointGridUnits(6, 4), pointGridUnits(7, 4)],
    marginBottomPx: [pointGridUnits(6, 4), pointGridUnits(7, 4)],
  },
  subtitle1: {
    fontSize: ['rem', 1],
    fontWeight: fontWeights.regular,
    letterSpacing: 0.15,
    lineHeightPx: typographyFoundation.leadingPx,
    marginTopPx: [pointGridUnits(2, 4), pointGridUnits(3, 4)],
    marginBottomPx: [pointGridUnits(2, 4), pointGridUnits(3, 4)],
  },
  subtitle2: {
    fontSize: ['rem', 0.875],
    fontWeight: fontWeights.medium,
    letterSpacing: 0.1,
    lineHeightPx: typographyFoundation.leadingPx,
    marginTopPx: [pointGridUnits(2, 4), pointGridUnits(3, 4)],
    marginBottomPx: [pointGridUnits(2, 4), pointGridUnits(3, 4)],
  },
  body1: {
    fontSize: ['rem', 1],
    fontWeight: fontWeights.regular,
    letterSpacing: 0.5,
    lineHeightPx: [pointGridUnits(6, 4), pointGridUnits(7, 4)],
    marginTopPx: [pointGridUnits(6, 4), pointGridUnits(7, 4)],
    marginBottomPx: [pointGridUnits(6, 4), pointGridUnits(7, 4)],
  },
  body2: {
    fontSize: ['rem', 0.875],
    fontWeight: fontWeights.regular,
    letterSpacing: 0.25,
    lineHeightPx: typographyFoundation.leadingPx,
    marginTopPx: typographyFoundation.leadingPx,
    marginBottomPx: typographyFoundation.leadingPx,
  },
  button: {
    fontSize: ['rem', 0.875],
    fontWeight: fontWeights.medium,
    letterSpacing: 0.75,
    textDecoration: 'none',
    textTransform: 'uppercase',
    lineHeightPx: typographyFoundation.leadingPx,
  },
  caption: {
    fontSize: ['rem', 0.75],
    fontWeight: fontWeights.regular,
    letterSpacing: 0.4,
    lineHeightPx: [pointGridUnits(4, 4)],
    marginTopPx: [pointGridUnits(4, 4)],
    marginBottomPx: [pointGridUnits(4, 4)],
  },
  overline: {
    fontSize: ['rem', 0.75],
    fontWeight: fontWeights.medium,
    letterSpacing: 1.5,
    textTransform: 'uppercase',
    lineHeightPx: [pointGridUnits(4, 4)],
    marginTopPx: [pointGridUnits(4, 4)],
    marginBottomPx: [pointGridUnits(4, 4)],
  },
};
